==> aptos_api_dart-0.4.1.tar.gz: generate_from_openapi.sh <==
#!/bin/bash

# Adapted from https://www.reddit.com/r/FlutterDev/comments/isokya/comment/hrhq53v/?utm_source=share&utm_medium=web2x&context=3

# For now use the locally built openapi-generator. We need to do this because I
# need the functionality of this not yet committed branch:
# https://github.com/Bdaya-Dev/openapi-generator/tree/dart-dio-handle-discriminator
# https://github.com/OpenAPITools/openapi-generator/pull/12295

# To get it, do this:
# git clone git@github.com:Bdaya-Dev/openapi-generator.git
# git checkout dart-dio-handle-discriminator
# docker build -t openapi-generator-cli .

OPENAPI_GENERATOR_CLI="openapi-generator-cli"

# For when we can use the mainline generator again:
# OPENAPI_GENERATOR_CLI="openapitools/openapi-generator-cli:latest"

set -e

BUILD_DIR="/tmp/build_dir"

# Ensure we have the necessary binaries.
which flutter
which dart

# Delete the existing files
rm -rf test/*
rm -rf lib/*
rm -rf doc/*
rm -rf .openapi-generator

# Get latest generator
# docker pull openapitools/openapi-generator-cli

# Generate code
docker run \
  --rm \
  --mount type=bind,source=$PWD,target=/hostdir \
  $OPENAPI_GENERATOR_CLI generate \
  -i https://raw.githubusercontent.com/aptos-labs/aptos-core/main/api/doc/openapi.yaml \
  -g dart-dio \
  -c /hostdir/openapi-generator.yaml \
  -o /hostdir

sleep 1

# Get deps if necessary
flutter pub get

sleep 1

# Complete the build
flutter pub run build_runner build

# Format code
find lib -type f -name "*.dart" | xargs dart format --fix
find test -type f -name "*.dart" | xargs dart format --fix

# Fix up the README
sed -i '' -E 's@ \(EXPERIMENTAL\)@@' README.md

# Make sure the user fixes up the version and bumps it
echo "WARNING: This script resets the version, make sure to bump it yourself manually from what it was"

echo

# Make sure the user adds the necessary serializers
echo "WARNING: Make sure to make the following changes manually for now: https://github.com/banool/aptos_api_dart/pull/2/files"

==> aptos_api_dart-0.5.4.tar.gz: generate_from_openapi.sh <==
#!/bin/bash

# Adapted from https://www.reddit.com/r/FlutterDev/comments/isokya/comment/hrhq53v/?utm_source=share&utm_medium=web2x&context=3

# For now use the locally built openapi-generator. We need to do this because I
# need the functionality of this not yet committed branch:
# https://github.com/Bdaya-Dev/openapi-generator/tree/dart-dio-handle-discriminator
# https://github.com/OpenAPITools/openapi-generator/pull/12295

# To get it, do this:
# git clone git@github.com:Bdaya-Dev/openapi-generator.git
# git checkout dart-dio-handle-discriminator
# docker build -t openapi-generator-cli .

OPENAPI_GENERATOR_CLI="openapi-generator-cli"

# For when we can use the mainline generator again:
# OPENAPI_GENERATOR_CLI="openapitools/openapi-generator-cli:latest"
# Get latest generator
# docker pull openapitools/openapi-generator-cli

set -e

BUILD_DIR="/tmp/build_dir"

# Ensure we have the necessary binaries.
which flutter
which dart

# Delete the existing files
rm -rf build
rm -rf test
rm -rf lib
rm -rf doc
rm -rf .openapi-generator

spec="$1"
if [[ $spec == "" ]]; then
    spec="https://raw.githubusercontent.com/aptos-labs/aptos-core/devnet/api/doc/spec.yaml"
fi

# Get current version
CURRENT_VERSION=`cat CHANGELOG.md | head -n 1 | perl -pe "s|.*?## ||"`

# Generate code
docker run \
  --rm \
  --mount type=bind,source=$PWD,target=/hostdir \
  $OPENAPI_GENERATOR_CLI \
  generate \
  -i $spec \
  -g dart-dio \
  -c /hostdir/openapi-generator.yaml \
  -o /hostdir

sleep 1

# Restore and bump the version in pubspec.yaml
sed -i '' -E "s/0.0.1/$CURRENT_VERSION/" pubspec.yaml
perl -i -pe 's/^(version:\s+\d+\.\d+\.)(\d+)$/$1.($2+1).$3/e' pubspec.yaml

# Get deps if necessary
flutter pub get

sleep 1

# Complete the build
flutter pub run build_runner build

# Format code
find lib -type f -name "*.dart" | xargs dart format --fix
find test -type f -name "*.dart" | xargs dart format --fix

# Fix up the README
sed -i '' -E 's@ \(EXPERIMENTAL\)@@' README.md

echo "Generated spec from: $spec" > source.txt
